@@ -81,6 +81,7 @@ bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94
 
 		
 	}
-	#attr(K1P,"unit") = "mol/kg"
-	#print(K1P);
+	attr(Ksi,"unit")     = "mol/kg-soln"
+	attr(Ksi,"pH scale") = "total hydrogen ion concentration"
+	return(K1P)
 }
