@@ -94,6 +94,7 @@ bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94
 		Ks = Ks*exp(lnkpok0[5]);
 		
 	}
-#attr(Ks,"unit") = "mol/kg"	
-print(Ks);
+attr(Ks,"unit") = "mol/kg-soln"	
+attr(Ks,"pH scale") = "free scale"
+return(Ks)
 }
